using System;
using Composite.Data;
using Composite.Data.Hierarchy;
using Composite.Data.Hierarchy.DataAncestorProviders;
using Composite.Validation.Validators;
using Microsoft.Practices.EnterpriseLibrary.Validation.Validators;


namespace C1WorkflowDemo.DataTypes
{
    /// <summary>
    /// This define a "data type". When C1 runs on SQL for instance, a table can come out if this.
    /// </summary>
    [AutoUpdateble]
    [KeyPropertyName("Id")]
    [LabelPropertyName("Name")]
    [ImmutableTypeId("{1D14905C-ECE3-4553-8179-030586758DE9}")]
    [DataScope(DataScopeIdentifier.PublicName)]
    [DataAncestorProvider(typeof(PropertyDataAncestorProvider))]
    [PropertyDataAncestorProvider("ProductCategoryId", typeof(IProductCategory), "Id", null)]
    [RelevantToUserType(UserType.Developer)]
    public interface IProduct : IData
    {
        [ImmutableFieldId("{D802F719-673D-47cb-99EA-B26D05EA861E}")]
        [StoreFieldType(PhysicalStoreFieldType.Guid)]
        Guid Id { get; set; }


        [ImmutableFieldId("{76B481E6-D9F1-44bd-8C02-2AE635C893BC}")]
        [StoreFieldType(PhysicalStoreFieldType.String, 64)]        
        [NotNullValidator()]
        string Name { get; set; }


        [ImmutableFieldId("{4A501B45-87D3-41b7-94A8-6EB6DA4E7B07}")]
        [StoreFieldType(PhysicalStoreFieldType.Guid)]
        [ForeignKey(typeof(IProductCategory), "Id")]
        Guid ProductCategoryId { get; set; }

        [ImmutableFieldId("{1DCDB729-61CD-4387-98E4-49AB08935029}")]
        [StoreFieldType(PhysicalStoreFieldType.Decimal, 12, 2)]
        [DecimalPrecisionValidator(2)]
        decimal Price { get; set; }


        [ImmutableFieldId("{597E3DA7-1AD0-4c99-84DB-50DB955BDC32}")]
        [StoreFieldType(PhysicalStoreFieldType.DateTime, IsNullable=true)]
        DateTime? Availability { get; set; }


        [ImmutableFieldId("{FBA1B9B0-C6F4-4298-8777-606330AC050D}")]
        [StoreFieldType(PhysicalStoreFieldType.String, 256)]
        string ShortDescription { get; set; }


        [ImmutableFieldId("{567A1058-557D-4bbb-8B8E-642190A7D546}")]
        [StoreFieldType(PhysicalStoreFieldType.LargeString)]
        string LongDescription { get; set; }
    }
}
