using System;
using Composite.Data;
using Composite.Data.Hierarchy;
using Composite.Data.Hierarchy.DataAncestorProviders;
using Microsoft.Practices.EnterpriseLibrary.Validation.Validators;


namespace C1WorkflowDemo.DataTypes
{
    /// <summary>
    /// This define a "data type". When C1 runs on SQL for instance, a table can come out if this.
    /// </summary>
    [AutoUpdateble]    
    [KeyPropertyName("Id")]    
    [LabelPropertyName("Name")]
    [ImmutableTypeId("{3EF1F9CC-D14B-4c63-AF4C-662089BFEDEA}")]
    [DataScope(DataScopeIdentifier.PublicName)]
    [DataAncestorProvider(typeof(NoAncestorDataAncestorProvider))]
    [RelevantToUserType(UserType.Developer)]
    public interface IProductCategory : IData
    {
        [ImmutableFieldId("{92A03F88-4A29-4182-9BCF-84080F1A2111}")]
        [StoreFieldType(PhysicalStoreFieldType.Guid)]
        Guid Id { get; set; }


        [ImmutableFieldId("{A8EEA24A-77AB-486c-AE6F-69EB224735A4}")]
        [StoreFieldType(PhysicalStoreFieldType.String, 64)]
        [NotNullValidator()]
        string Name { get; set; }


        [ImmutableFieldId("{D6085CAD-E74E-4e4b-8352-B31D9932EDCC}")]
        [StoreFieldType(PhysicalStoreFieldType.String, 512)]
        string Description { get; set; }
    }
}
