﻿using System;
using System.Collections.Generic;
using C1WorkflowDemo.DataTypes;
using Composite.Application;
using Composite.Data;
using Composite.Data.DynamicTypes;
using Composite.EventSystem;

namespace C1WorkflowDemo
{
    /// <summary>
    /// Here we hook up on the C1 start event - checking that out data store has been created, and if not we create it.
    /// The hook up is done by the ApplicationStartupAttribute on this class.
    /// </summary>
    [ApplicationStartup]
    public class CompositeC1StartupHandler
    {
        /// <summary>
        /// This handler will be called before Composite initialization. The data layer cannot be used here.
        /// </summary>
        public static void OnBeforeInitialize()
        {
        }

        /// <summary>
        /// Ensure that data stores are created for our data types...
        /// This handler will be called after initialization of Composite core.
        /// </summary>
        public static void OnInitialized()
        {
            List<Type> knownInterfaces = DataFacade.GetAllInterfaces();
            bool addedNewDataTypes = false;

            if (knownInterfaces.Contains(typeof(IProductCategory)) == false)
            {
                DataTypeDescriptor productCategoryTypeDescriptor = DynamicTypeManager.BuildNewDataTypeDescriptor(typeof(IProductCategory));
                DynamicTypeManager.CreateStore(productCategoryTypeDescriptor, false);
                addedNewDataTypes = true;
            }

            if (knownInterfaces.Contains(typeof(IProduct)) == false)
            {
                DataTypeDescriptor productTypeDescriptor = DynamicTypeManager.BuildNewDataTypeDescriptor(typeof(IProduct));
                DynamicTypeManager.CreateStore(productTypeDescriptor, false);
                addedNewDataTypes = true;
            }

            if (addedNewDataTypes == true)
            {
                GlobalEventSystemFacade.FlushTheSystem();
            }
        }
    }
}
