using System;
using System.Workflow.Activities;
using C1WorkflowDemo.DataTypes;
using Composite.Actions;
using Composite.Data;
using Composite.Workflow;


namespace C1WorkflowDemo.Workflows
{
    [AllowPersistingWorkflow(WorkflowPersistingType.Idle)]
    public sealed partial class EditProductWorkflow : Composite.Workflow.Activities.FormsWorkflow
    {
        bool _valid = false;


        public EditProductWorkflow()
        {
            InitializeComponent();
        }



        private void IsValid(object sender, ConditionalEventArgs e)
        {
            e.Result = _valid;
        }


        // Initialization of the workflows state - the element that 'Edit' was executed on is grabbed and stored in the Bindings 
        // (making the data visible to the Form UI).
        private void initializeCodeActivity_ExecuteCode(object sender, EventArgs e)
        {
            DataEntityToken dataEntityToken = (DataEntityToken)this.EntityToken;

            IProduct product = (IProduct)dataEntityToken.Data;

            this.Bindings.Add("Product", product);
        }



        private void editCodeActivity_Validatoin_ExecuteCode(object sender, EventArgs e)
        {
            _valid = true;

            IProduct product = this.GetBinding<IProduct>("Product");

            if ((product.Price % 0.05M) != 0.0M)
            {
                _valid = false;

                //              This will show a baloon on a field - typically displaying a validation error message
                //                this.ShowFieldMessage("Product.Price", "The price should be divisible with 0.05");
            }
        }



        private void saveCodeActivity_ExecuteCode(object sender, EventArgs e)
        {
            // Grab product data object from form bindings:
            IProduct product = this.GetBinding<IProduct>("Product");
            IProductCategory productCategory = (IProductCategory)product.GetReferenced("ProductCategoryId");

            // Save it...
            DataFacade.Update(product);

            // Disable the save button on client, so user can see stuff was savced OK.
            this.SetSaveStatus(true);

            // Update the tree
            SpecificTreeRefresher specificTreeRefresher = this.CreateSpecificTreeRefresher();
            specificTreeRefresher.PostRefreshMesseges(productCategory.GetDataEntityToken());
        }
    }
}
